@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 # author: Ethosa
 
-from CSharpToCppTranslator import CSharpToCppTranslator
+from .CSharpToCppTranslator import CSharpToCppTranslator
 
-__version__ = "0.0.1"
+__version__ = "0.0.2"
 __copyright__ = "2019"
 __authors__ = ["Ethosa", "Konard"]
\ No newline at end of file
